@@ -62,7 +62,7 @@ static dBox box[NUM];
 // this is called by space.collide when two objects in space are
 // potentially colliding.
 
-static void nearCallback (void *data, dGeomID o1, dGeomID o2)
+static void nearCallback (void *, dGeomID o1, dGeomID o2)
 {
   // exit without doing anything if the two bodies are connected by a joint
   dBodyID b1 = dGeomGetBody(o1);
@@ -127,10 +127,6 @@ int main (int argc, char **argv)
   fn.command = 0;
   fn.stop = 0;
   fn.path_to_textures = DRAWSTUFF_TEXTURE_PATH;
-  if(argc==2)
-    {
-        fn.path_to_textures = argv[1];
-    }
 
   // create world
   dInitODE2(0);
@@ -149,7 +145,7 @@ int main (int argc, char **argv)
     m.setBox (1,SIDE,SIDE,SIDE);
     m.adjust (MASS);
     body[i].setMass (&m);
-    body[i].setData ((void*)(size_t)i);
+    body[i].setData ((void*)(dsizeint)i);
 
     box[i].create (space,SIDE,SIDE,SIDE);
     box[i].setBody (body[i]);
