@@ -508,13 +508,6 @@ void dJointSetPUAxis2( dJointID j, dReal x, dReal y, dReal z )
 }
 
 
-void dJointSetPUAxisP( dJointID id, dReal x, dReal y, dReal z )
-{
-    dJointSetPUAxis3( id, x, y, z );
-}
-
-
-
 void dJointSetPUAxis3( dJointID j, dReal x, dReal y, dReal z )
 {
     dxJointPU* joint = ( dxJointPU* ) j;
@@ -527,6 +520,46 @@ void dJointSetPUAxis3( dJointID j, dReal x, dReal y, dReal z )
 }
 
 
+void dJointSetPUAxisP(dJointID id, dReal x, dReal y, dReal z)
+{
+    dJointSetPUAxis3(id, x, y, z);
+}
+
+
+void dJointSetPUParam(dJointID j, int parameter, dReal value)
+{
+    dxJointPU *joint = (dxJointPU *)j;
+    dUASSERT(joint, "bad joint argument");
+    checktype(joint, PU);
+
+    switch (parameter & 0xff00)
+    {
+        case dParamGroup1:
+            joint->limot1.set(parameter, value);
+            break;
+        case dParamGroup2:
+            joint->limot2.set(parameter & 0xff, value);
+            break;
+        case dParamGroup3:
+            joint->limotP.set(parameter & 0xff, value);
+            break;
+    }
+}
+
+void dJointAddPUTorques(dJointID j, dReal torque1, dReal torque2)
+{
+    dxJointPU *joint = (dxJointPU *)j;
+    dAASSERT(joint);
+    checktype(joint, PU);
+
+    dVector3 axis;
+    joint->buildFirstBodyTorqueVector(axis, torque1, torque2);
+
+    if (joint->node[0].body != 0)
+        dBodyAddTorque(joint->node[0].body, axis[0], axis[1], axis[2]);
+    if (joint->node[1].body != 0)
+        dBodyAddTorque(joint->node[1].body, -axis[0], -axis[1], -axis[2]);
+}
 
 
 void dJointGetPUAngles( dJointID j, dReal *angle1, dReal *angle2 )
@@ -611,26 +644,6 @@ dReal dJointGetPUAngle2Rate( dJointID j )
 }
 
 
-void dJointSetPUParam( dJointID j, int parameter, dReal value )
-{
-    dxJointPU* joint = ( dxJointPU* ) j;
-    dUASSERT( joint, "bad joint argument" );
-    checktype( joint, PU );
-
-    switch ( parameter & 0xff00 )
-    {
-    case dParamGroup1:
-        joint->limot1.set( parameter, value );
-        break;
-    case dParamGroup2:
-        joint->limot2.set( parameter & 0xff, value );
-        break;
-    case dParamGroup3:
-        joint->limotP.set( parameter & 0xff, value );
-        break;
-    }
-}
-
 void dJointGetPUAnchor( dJointID j, dVector3 result )
 {
     dxJointPU* joint = ( dxJointPU* ) j;
