@@ -31,7 +31,7 @@ struct dxStepperProcessingCallContext;
 sizeint dxEstimateQuickStepMemoryRequirements(
     dxBody * const *body, unsigned int nb, dxJoint * const *_joint, unsigned int _nj);
 unsigned dxEstimateQuickStepMaxCallCount(
-    unsigned activeThreadCount, unsigned allowedThreadCount);
+    unsigned activeThreadCount, unsigned steppingAllowedThreadCount, unsigned lcpAllowedThreadCount);
 
 void dxQuickStepIsland(const dxStepperProcessingCallContext *callContext);
 
