@@ -1,6 +1,6 @@
 /*************************************************************************
  *                                                                       *
- * ODER's Utilities Library. Copyright (C) 2008-2019 Oleh Derevenko.     *
+ * ODER's Utilities Library. Copyright (C) 2008-2024 Oleh Derevenko.     *
  * All rights reserved.  e-mail: odar@eleks.com (change all "a" to "e")  *
  *                                                                       *
  * This library is free software; you can redistribute it and/or         *
@@ -65,7 +65,7 @@ struct CTypeStandardLess
 /*
  *	Implementation Note:
  *	The array is intended to store static constant data. 
- *	Therefore CElementEqualType should not ever need a nontrivial constructor
+ *	Therefore CElementEqualType should never need a nontrivial constructor
  *	and it is acceptable to have it as template parameter.
  */
 
@@ -148,7 +148,7 @@ private:
 /*
  *	Implementation Note:
  *	The array is intended to store static constant data. 
- *	Therefore CElementLessType and CElementEqualType should not ever need 
+ *	Therefore CElementLessType and CElementEqualType should never need 
  *	a nontrivial constructor and it is acceptable to have them 
  *	as template parameters.
  */
